@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonaditaskqueries.h"
@@ -71,7 +53,7 @@ void TaskQueries::setWorkdayPollInterval(int interval)
 
 TaskQueries::TaskResult::Ptr TaskQueries::findAll() const
 {
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<TaskQueries*>(this));
     auto predicate = [this] (const Akonadi::Item &item) {
         return m_serializer->isTaskItem(item);
     };
@@ -83,7 +65,7 @@ TaskQueries::TaskResult::Ptr TaskQueries::findChildren(Domain::Task::Ptr task) c
 {
     Akonadi::Item item = m_serializer->createItemFromTask(task);
     auto &query = m_findChildren[item.id()];
-    auto fetch = m_helpers->fetchSiblings(item);
+    auto fetch = m_helpers->fetchSiblings(item, const_cast<TaskQueries*>(this));
     auto predicate = [this, task] (const Akonadi::Item &childItem) {
         return m_serializer->isTaskChild(task, childItem);
     };
@@ -95,7 +77,7 @@ TaskQueries::ProjectResult::Ptr TaskQueries::findProject(Domain::Task::Ptr task)
 {
     Akonadi::Item childItem = m_serializer->createItemFromTask(task);
     auto &query = m_findProject[childItem.id()];
-    auto fetch = m_helpers->fetchTaskAndAncestors(task);
+    auto fetch = m_helpers->fetchTaskAndAncestors(task, const_cast<TaskQueries*>(this));
     auto predicate = [this, childItem] (const Akonadi::Item &item) {
         return m_serializer->isProjectItem(item);
     };
@@ -110,7 +92,7 @@ TaskQueries::DataSourceResult::Ptr TaskQueries::findDataSource(Domain::Task::Ptr
 {
     Akonadi::Item item = m_serializer->createItemFromTask(task);
     auto &query = m_findDataSource[item.id()];
-    auto fetch = m_helpers->fetchItemCollection(item);
+    auto fetch = m_helpers->fetchItemCollection(item, const_cast<TaskQueries*>(this));
     auto predicate = [] (const Akonadi::Collection &) { return true; };
 
     m_integrator->bind("TaskQueries::findDataSource", query, fetch, predicate);
@@ -120,7 +102,7 @@ TaskQueries::DataSourceResult::Ptr TaskQueries::findDataSource(Domain::Task::Ptr
 TaskQueries::TaskResult::Ptr TaskQueries::findTopLevel() const
 {
     Q_ASSERT(m_cache);
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<TaskQueries*>(this));
     auto predicate = [this] (const Akonadi::Item &item) {
         // Tasks with no parent, or whose parent is a project (not a task)
         if (!m_serializer->isTaskItem(item))
@@ -151,7 +133,7 @@ TaskQueries::TaskResult::Ptr TaskQueries::findTopLevel() const
 
 TaskQueries::TaskResult::Ptr TaskQueries::findInboxTopLevel() const
 {
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<TaskQueries*>(this));
     auto predicate = [this] (const Akonadi::Item &item) {
         // Tasks without a parent (neither task nor project)
         return m_serializer->isTaskItem(item) && m_serializer->relatedUidFromItem(item).isEmpty();
@@ -167,7 +149,7 @@ TaskQueries::TaskResult::Ptr TaskQueries::findWorkdayTopLevel() const
         m_today = Utils::DateTime::currentDate();
     }
 
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<TaskQueries*>(this));
     auto isWorkdayItem = [this] (const Akonadi::Item &item) {
         if (!m_serializer->isTaskItem(item))
             return false;
@@ -223,7 +205,7 @@ TaskQueries::ContextResult::Ptr TaskQueries::findContexts(Domain::Task::Ptr task
     m_findContextsItem[taskItemId] = taskItem;
 
     auto &query = m_findContexts[taskItemId];
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<TaskQueries*>(this));
     auto predicate = [this, taskItemId] (const Akonadi::Item &contextItem) {
         auto context = m_serializer->createContextFromItem(contextItem);
         if (!context)
