@@ -11,9 +11,9 @@
 #include "akonadi/akonadiapplicationselectedattribute.h"
 #include "akonadi/akonaditimestampattribute.h"
 
-#include <AkonadiCore/Akonadi/Collection>
-#include <AkonadiCore/Akonadi/EntityDisplayAttribute>
-#include <AkonadiCore/Akonadi/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/Item>
 #include <KCalCore/Todo>
 #if __has_include(<kcalcore_version.h>)
 #include <kcalcore_version.h>
@@ -580,17 +580,10 @@ private slots:
         originalTodo->setCustomProperty(Serializer::customPropertyAppName(),
                                         Serializer::customPropertyContextList(),
                                         QStringLiteral("context1,context2"));
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
         KCalCore::Attendee originalAttendee(QStringLiteral("John Doe"),
                                             QStringLiteral("j@d.com"),
                                             true,
                                             KCalCore::Attendee::Accepted);
-#else
-        KCalCore::Attendee::Ptr originalAttendee(new KCalCore::Attendee(QStringLiteral("John Doe"),
-                                                                        QStringLiteral("j@d.com"),
-                                                                        true,
-                                                                        KCalCore::Attendee::Accepted));
-#endif
         originalTodo->addAttendee(originalAttendee);
 
         // ... as payload of an item...
@@ -645,7 +638,6 @@ private slots:
             updatedTodo->recurrence()->setDaily(1);
 
         for (int i = 0; i < updatedAttachmentData.size(); i++) {
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
             KCalCore::Attachment attachment(QByteArray{});
             if (!updatedAttachmentData.at(i).isEmpty())
                 attachment.setDecodedData(updatedAttachmentData.at(i));
@@ -653,15 +645,6 @@ private slots:
                 attachment.setUri(updatedAttachmentUris.at(i));
             attachment.setMimeType(updatedAttachmentMimeTypes.at(i));
             attachment.setLabel(updatedAttachmentLabels.at(i));
-#else
-            KCalCore::Attachment::Ptr attachment(new KCalCore::Attachment(QByteArray()));
-            if (!updatedAttachmentData.at(i).isEmpty())
-                attachment->setDecodedData(updatedAttachmentData.at(i));
-            else
-                attachment->setUri(updatedAttachmentUris.at(i));
-            attachment->setMimeType(updatedAttachmentMimeTypes.at(i));
-            attachment->setLabel(updatedAttachmentLabels.at(i));
-#endif
             updatedTodo->addAttachment(attachment);
         }
 
@@ -1129,19 +1112,11 @@ private slots:
         QCOMPARE(todo->attachments().size(), attachments.size());
         for (int i = 0; i < attachments.size(); i++) {
             auto attachment = todo->attachments().at(i);
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
             QCOMPARE(attachment.isUri(), attachments.at(i).isUri());
             QCOMPARE(QUrl(attachment.uri()), attachments.at(i).uri());
             QCOMPARE(attachment.decodedData(), attachments.at(i).data());
             QCOMPARE(attachment.label(), attachments.at(i).label());
             QCOMPARE(attachment.mimeType(), attachments.at(i).mimeType());
-#else
-            QCOMPARE(attachment->isUri(), attachments.at(i).isUri());
-            QCOMPARE(QUrl(attachment->uri()), attachments.at(i).uri());
-            QCOMPARE(attachment->decodedData(), attachments.at(i).data());
-            QCOMPARE(attachment->label(), attachments.at(i).label());
-            QCOMPARE(attachment->mimeType(), attachments.at(i).mimeType());
-#endif
         }
 
         if (!todoUid.isEmpty()) {
